@@ -104,8 +104,12 @@ class Benchmark(object):
             row['mean'] = self.results[key]['total']/row['runs']
             row['total'] = self.results[key]['total']
             row['sumOfSquares'] = self.results[key]['sumOfSq']
-            row['var'] = (row['sumOfSquares']-pow(row['total'], 2)/row['runs'])/(row['runs']-1)
-            row['sd'] = math.sqrt(row['var'])
+            if row['runs'] > 1:
+                row['var'] = (row['sumOfSquares']-pow(row['total'], 2)/row['runs'])/(row['runs']-1)
+                row['sd'] = math.sqrt(row['var'])
+            else:
+                row['var'] = 'NA'
+                row['sd'] = 'NA'            
             self.table.append(row)
         
         self.table = sorted(self.table, key=operator.itemgetter('mean'))
@@ -113,7 +117,10 @@ class Benchmark(object):
             v['rank'] = i+1
         
         self.__testAndRunFn(self.__tearDown)
-        
+    
+    def getTotalRuns(self):
+        return self.__n*len(self.table)
+    
     def __asMarkdown(self, header, table):
         maxSize = self.__columnWidths(header, table)
         lines = []
