@@ -18,14 +18,16 @@ class BenchmarkProgram(object):
         
         benchmarks = self.loadFromModule(self.module)
         
+        totalRuns = 0
         objects = []
         for obj in benchmarks:
             obj = obj(**kwargs)
             obj.run()
             objects.append(obj)
+            totalRuns += obj.getTotalRuns()
         
         title = 'Benchmark Report'
-        info = 'The functions above were run in random, non-consecutive order by'
+        info = 'Each of the above %s runs were run in random, non-consecutive order by' % str(totalRuns)
         info += os.linesep
         info += '`benchmark` v' + __VERSION__ + ' (http://jspi.es/benchmark) with Python ' + platform.python_version()
         info += os.linesep
